Summary:		PowerDNS is a Versatile Database Driven Nameserver
Name:			pdns-server
Version:		3.1
Release:		1.4
Epoch:			0
License:		GPL
Group:			System/Servers
URL:			http://www.powerdns.com/
Source0:		http://downloads.powerdns.com/releases/pdns-%{version}.tar.gz
Patch0:			pdns-3.1-init.patch

Source1:		http://downloads.powerdns.com/documentation/html.tar.gz

BuildRequires:		autoconf automake
BuildRequires:		gcc gcc-c++
BuildRequires:		zlib-devel
BuildRequires:		lua-devel
BuildRequires:		boost-devel >= 1.34.0
BuildRequires:		sqlite-devel >= 3.0.0

Requires:		lua
Requires:		boost-serialization >= 1.34.0
Requires:		boost-program-options >= 1.34.0
Requires:		sqlite >= 3.0.0

Provides:		nameserver pdns-server

BuildRoot:		%{_tmppath}/%{name}-%{version}-root


%description
PowerDNS is a versatile nameserver which supports a large number
of different backends ranging from simple zonefiles to relational
databases and load balancing/failover algorithms.

This RPM comes with support for MySQL, PostgreSQL, Bind zonefiles and the 'pipe
backend' availible as external packages.

%package		tools
Summary:		DNS tools for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}

%description		tools
This package contains the DNS tools for the PowerDNS nameserver.

%package		backend-pipe
Summary:		Pipe/coprocess backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}

%description		backend-pipe
This package contains the pipe backend for the PowerDNS nameserver. This
allows PowerDNS to retrieve domain info from a process that accepts
questions on stdin and returns answers on stdout. 

%package		backend-mysql
Summary:		MySQL backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		mysql
BuildRequires:		mysql-devel

%description		backend-mysql
This package contains the MySQL backend for the PowerDNS nameserver.

%package		backend-postgresql
Summary:		postgesql backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		postgresql
BuildRequires:		postgresql-devel

%description		backend-postgresql
This package contains the postgesql backend for the PowerDNS nameserver.

%package		backend-sqlite3
Summary:		sqlite3 backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}

%description		backend-sqlite3
This package contains the sqlite3 backend for the PowerDNS nameserver.

%package		backend-ldap
Summary:		LDAP backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		openldap
BuildRequires:		openldap-devel

%description		backend-ldap
This package contains the LDAP backend for the PowerDNS nameserver.

%package		devel
Summary:		Development headers and libraries for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		%{name}-backend-pipe = %{version}
Requires:		%{name}-backend-mysql = %{version}
Requires:		%{name}-backend-pgsql = %{version}
Requires:		%{name}-backend-sqlite = %{version}
Requires:		%{name}-backend-ldap = %{version}

%description		devel
Development headers and libraries for %{name}

%prep
%setup -q -n pdns-%{version} -a1
%patch0 -p0 -b .init

%build
%configure \
    --sysconfdir=%{_sysconfdir}/powerdns \
    --libdir=%{_libdir} \
    --with-socketdir=/var/run/pdns-server \
    --with-modules="" \
    --with-dynmodules="pipe gmysql gpgsql gsqlite3 ldap"
%{__make}

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/
install -d $RPM_BUILD_ROOT%{_localstatedir}/run/pdns-server

%{__make} DESTDIR=$RPM_BUILD_ROOT install

# fix the config
mv $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf-dist $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf

cat >> $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf << EOF
module-dir=%{_libdir}
socket-dir=/var/run/pdns-server
setuid=powerdns
setgid=powerdns
launch=bind
#recursor=127.0.0.1:5300
EOF

chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf

# install sysv scripts
install -d $RPM_BUILD_ROOT%{_initrddir}
install -m755 pdns/pdns $RPM_BUILD_ROOT%{_initrddir}/pdns-server

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%pre
if [ -z "`/usr/bin/id -g powerdns 2>/dev/null`" ]; then
    /usr/sbin/groupadd -g 25 -r -f powerdns 2>&1 || :
fi
if [ -z "`/usr/bin/id -u powerdns 2>/dev/null`" ]; then
    /usr/sbin/useradd -u 25 -r -M -d /tmp  -s /sbin/nologin -c "PowerDNS" -g powerdns powerdns 2>&1 || :
fi

%post
/sbin/ldconfig
/sbin/chkconfig --add pdns-server

%preun
if [ $1 -eq 0 ]; then
    /sbin/service pdns-server stop >/dev/null 2>&1 || :
    /sbin/chkconfig --del pdns-server

    if [ -d /var/run/pdns-server ]; then
	rm -rf /var/run/pdns-server/*
    fi
fi

%postun
/sbin/ldconfig
if [ $1 -eq 0 ]; then
    rm -rf %{_localstatedir}/run/pdns-server/
    /usr/sbin/userdel powerdns 2>/dev/null || :
    /usr/sbin/groupdel powerdns 2>/dev/null || :
else
    /sbin/service pdns-server condrestart >/dev/null 2>&1
fi

%files
%defattr(-,root,root)
%doc ChangeLog HACKING INSTALL README TODO html
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/pdns.conf
%config(noreplace) %attr(0755,root,root) %{_initrddir}/pdns-server
%dir %{_sysconfdir}/powerdns
%dir %attr(0755,powerdns,powerdns) /var/run/pdns-server
%{_bindir}/pdns_control
%{_bindir}/pdnssec
%{_sbindir}/pdns_server
%{_mandir}/man8/pdns_control.8*
%{_mandir}/man8/pdns_server.8*

%files tools
%defattr(-,root,root)
%{_bindir}/dnsreplay
%{_bindir}/zone2sql
%{_bindir}/zone2ldap
%{_mandir}/man8/zone2sql.8*

%files backend-pipe
%defattr(-,root,root)
%{_libdir}/libpipebackend.so

%files backend-mysql
%defattr(-,root,root)
%{_libdir}/libgmysqlbackend.so

%files backend-postgresql
%defattr(-,root,root)
%{_libdir}/libgpgsqlbackend.so

%files backend-sqlite3
%defattr(-,root,root)
%{_libdir}/libgsqlite3backend.so

%files backend-ldap
%defattr(-,root,root)
%{_libdir}/libldapbackend.so

%files devel
%defattr(-,root,root)
%{_libdir}/*.la
%{_libdir}/*.a

%changelog
* Fri May 04 2012 Kees Monshouwer <km|monshouwer_com> 3.1-1
- Update to 3.1

* Sun Jan 08 2012 Kees Monshouwer <km|monshouwer_com> 3.0.1-1
- Update to 3.0.1

* Mon Jul 22 2011 Kees Monshouwer <km@monshouwer.com> 3.0-1
- Initial build for PowerDNS 3.0
